## 国债实际长期利率平均值

接口：us_trltr

描述：国债实际长期利率平均值

限量：单次最大可获取2000行数据，可循环获取

权限：用户积累120积分可以使用，积分越高频次越高。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| fields | str | N | 指定字段 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| ltr_avg | float | Y | 实际平均利率LT Real Average (10> Yrs) |

接口调用

```python
pro = ts.pro_api()

df = pro.us_trltr(start_date='20180101', end_date='20200327')


#获取指定字段
df = pro.us_trltr(start_date='20180101', end_date='20200327', fields='ltr_avg')
```

数据样例

```python
date ltr_avg
0     20200327   -0.02
```